v0.4.0
======

Features
--------

- Moved 'set' to the top-level 'pytest_home'.


v0.3.0
======

Features
--------

- Exposed 'set' function for setting the home dir outside a fixture.


v0.2.0
======

Features
--------

- For better Git compatibility, set HOME unconditionally. (#1)


v0.1.1
======

Bugfixes
--------

- For better Git compatibility, suppress HOMEDRIVE and HOMEPATH vars. (#1)


v0.1.0
======

Features
--------

- Added alt_home fixture (#54710829)
